@@ -39,7 +39,7 @@ energy = 15000
 ###########################
 # 3S+2D goniometer (simplified ID01 goniometer, sample mu,eta,phi detector
 # nu,del
-qconv = xu.experiment.QConversion(['z+', 'y-', 'z-'], ['z+', 'y-'], [1, 0, 0])
+qconv = xu.experiment.QConversion(["z+", "y-", "z-"], ["z+", "y-"], [1, 0, 0])
 # convention for coordinate system: x downstream; z upwards; y to the "outside"
 # (righthanded)
 # QConversion will set up the goniometer geometry. So the first argument
@@ -73,14 +73,15 @@ ang = None
 tbegin = time.time()
 print("time  error (code)      qvec             angles")
 for i in range(100):
-
     qvec = numpy.array((0, 0, i * 0.01))
     t0 = time.time()
     ang, qerror, errcode = xu.Q2AngFit(qvec, hxrd, bounds, startvalues=ang)
     t1 = time.time()
 
-    print("%.4f: %.3g (%d) %s %s" % (t1 - t0, qerror, errcode,
-                                     str(qvec), str(ang)))
+    print(
+        "%.4f: %.3g (%d) %s %s"
+        % (t1 - t0, qerror, errcode, str(qvec), str(ang))
+    )
 
 tend = time.time()
 print("Total time needed: %.2fsec" % (tend - tbegin))
