@@ -23,9 +23,9 @@ import numpy
 import xrayutilities as xu
 
 # plot settings for matplotlib
-mpl.rcParams['font.family'] = 'serif'
-mpl.rcParams['font.size'] = 20.0
-mpl.rcParams['axes.labelsize'] = 'large'
+mpl.rcParams["font.family"] = "serif"
+mpl.rcParams["font.size"] = 20.0
+mpl.rcParams["axes.labelsize"] = "large"
 
 # global setting for the experiment
 sample = "rsm"  # sample name used also as file name for the data file
@@ -46,16 +46,19 @@ ttalign = 69.1283
 [omnominal, _, _, ttnominal] = hxrd.Q2Ang(Si.Q(0, 0, 4))
 
 # read the data from the xrdml files
-om, tt, psd = xu.io.getxrdml_map(sample + '_%d.xrdml.bz2', [1, 2, 3, 4, 5],
-                                 path='data')
+om, tt, psd = xu.io.getxrdml_map(
+    sample + "_%d.xrdml.bz2", [1, 2, 3, 4, 5], path="data"
+)
 
 # determine offset of substrate peak from experimental values (optional)
 omalign, ttalign, p, cov = xu.analysis.fit_bragg_peak(
-    om, tt, psd, omalign, ttalign, hxrd, plot=False)
+    om, tt, psd, omalign, ttalign, hxrd, plot=False
+)
 
 # convert angular coordinates to reciprocal space + correct for offsets
-qx, qy, qz = hxrd.Ang2Q(om, tt, delta=[omalign - omnominal,
-                                       ttalign - ttnominal])
+qx, qy, qz = hxrd.Ang2Q(
+    om, tt, delta=[omalign - omnominal, ttalign - ttnominal]
+)
 
 # calculate data on a regular grid of 200x201 points
 gridder = xu.Gridder2D(200, 600)
@@ -64,9 +67,9 @@ INT = xu.maplog(gridder.data.transpose(), 6, 0)
 
 # plot the intensity as contour plot
 plt.figure()
-cf = plt.contourf(gridder.xaxis, gridder.yaxis, INT, 100, extend='min')
-plt.xlabel(r'$Q_{[110]}$ ($\mathrm{\AA}^{-1}$)')
-plt.ylabel(r'$Q_{[001]}$ ($\mathrm{\AA}^{-1}$)')
+cf = plt.contourf(gridder.xaxis, gridder.yaxis, INT, 100, extend="min")
+plt.xlabel(r"$Q_{[110]}$ ($\mathrm{\AA}^{-1}$)")
+plt.ylabel(r"$Q_{[001]}$ ($\mathrm{\AA}^{-1}$)")
 cb = plt.colorbar(cf)
 cb.set_label(r"$\log($Int$)$ (cps)")
 
@@ -78,24 +81,28 @@ plt.tight_layout()
 qycpos, qzcpos = [0, 4.5]
 omp, _, _, ttp = hxrd.Q2Ang(0, qycpos, qzcpos, trans=False)
 qzc, qzint, cmask = xu.analysis.get_radial_scan(
-    [qy, qz], psd, (qycpos, qzcpos), 1001, 0.155, intdir='2theta')
+    [qy, qz], psd, (qycpos, qzcpos), 1001, 0.155, intdir="2theta"
+)
 
 # show used data on the reciprocal space map
-plt.tricontour(qy, qz, cmask, (0.999,), colors='r')
+plt.tricontour(qy, qz, cmask, (0.999,), colors="r")
 
 # show possible integration directions
 f = 1.02
-plt.plot([qycpos/f, qycpos*f], [qzcpos/f, qzcpos*f], label='radial')
-a = numpy.radians(numpy.linspace(- 2, 2, 100))
-plt.plot(qycpos*numpy.cos(a)+qzcpos*numpy.sin(a),
-         -qycpos*numpy.sin(a)+qzcpos*numpy.cos(a), label='Omega')
-qx, qy, qz = hxrd.Ang2Q(omp, ttp+numpy.linspace(-2, 2, 100))
-plt.plot(qy, qz, label='2Theta')
+plt.plot([qycpos / f, qycpos * f], [qzcpos / f, qzcpos * f], label="radial")
+a = numpy.radians(numpy.linspace(-2, 2, 100))
+plt.plot(
+    qycpos * numpy.cos(a) + qzcpos * numpy.sin(a),
+    -qycpos * numpy.sin(a) + qzcpos * numpy.cos(a),
+    label="Omega",
+)
+qx, qy, qz = hxrd.Ang2Q(omp, ttp + numpy.linspace(-2, 2, 100))
+plt.plot(qy, qz, label="2Theta")
 plt.legend()
 
 # plot line cut
 plt.figure()
 plt.semilogy(qzc, qzint)
-plt.xlabel(r'scattering angle (deg)')
-plt.ylabel(r'intensity (arb. u.)')
+plt.xlabel(r"scattering angle (deg)")
+plt.ylabel(r"intensity (arb. u.)")
 plt.tight_layout()
