@@ -17,17 +17,32 @@
 # Copyright (c) 2010-2020, 2023 Dominik Kriegner <dominik.kriegner@gmail.com>
 # Copyright (C) 2022 Vinícius Frehse <vinifrehse@gmail.com>
 
-from . import elements
-from .atom import Atom
-from .cif import CIFFile, cifexport
-from .database import (DataBase, add_f0_from_intertab, add_f0_from_xop,
-                       add_f1f2_from_ascii_file, add_f1f2_from_henkedb,
-                       add_f1f2_from_kissel, add_mass_from_NIST,
-                       init_material_db)
-from .material import (Alloy, Amorphous, Crystal, CubicAlloy,
-                       CubicElasticTensor, HexagonalElasticTensor, Material,
-                       MonoclinicElasticTensor, PseudomorphicMaterial,
-                       TrigonalElasticTensor, WZTensorFromCub)
-from .plot import show_reciprocal_space_plane
+from . import elements  # noqa: F401
+from .atom import Atom  # noqa: F401
+from .cif import CIFFile, cifexport  # noqa: F401
+from .database import (  # noqa: F401
+    DataBase,
+    add_f0_from_intertab,
+    add_f0_from_xop,
+    add_f1f2_from_ascii_file,
+    add_f1f2_from_henkedb,
+    add_f1f2_from_kissel,
+    add_mass_from_NIST,
+    init_material_db,
+)
+from .material import (  # noqa: F401
+    Alloy,
+    Amorphous,
+    Crystal,
+    CubicAlloy,
+    CubicElasticTensor,
+    HexagonalElasticTensor,
+    Material,
+    MonoclinicElasticTensor,
+    PseudomorphicMaterial,
+    TrigonalElasticTensor,
+    WZTensorFromCub,
+)
+from .plot import show_reciprocal_space_plane  # noqa: F401
 from .predefined_materials import *  # noqa: F403
-from .spacegrouplattice import SGLattice, SymOp
+from .spacegrouplattice import SGLattice, SymOp  # noqa: F401
