@@ -13,29 +13,30 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
-# Copyright (c) 2015-2024 Dominik Kriegner <dominik.kriegner@gmail.com>
+# Copyright (c) 2015-2025 Dominik Kriegner <dominik.kriegner@gmail.com>
 
+"""module handling physical properties of elements.
+
+The Atom class manages the database access for atomic scattering factors and
+the atomic mass.
 """
-module containing the Atom class which handles the database access for atomic
-scattering factors and the atomic mass.
-"""
+
 import hashlib
-import os.path
 import re
+from importlib.resources import files
 
 import numpy
 
 from .. import config, utilities
-from . import __path__, database
+from . import database
 
-_db = database.DataBase(os.path.join(__path__[0], "data", config.DBNAME))
+dbfile = files("xrayutilities.materials") / "data" / config.DBNAME
+_db = database.DataBase(dbfile)
 _db.Open()
 
 
 def get_key(*args):
-    """
-    generate a hash key for several possible types of arguments
-    """
+    """Generate a hash key for several possible types of arguments"""
     tup = []
     for a in args:
         if isinstance(a, numpy.ndarray):
@@ -52,23 +53,23 @@ class Atom:
 
     def __init__(self, name, num):
         self.name = name
-        self.ostate = re.sub('[A-Za-z]', '', name)
-        for r, o in zip(('dot', 'p', 'm'), ('.', '+', '-')):
+        self.ostate = re.sub("[A-Za-z]", "", name)
+        for r, o in zip(("dot", "p", "m"), (".", "+", "-")):
             self.ostate = self.ostate.replace(o, r)
 
-        self.basename = re.sub('[^A-Za-z]', '', name)
+        self.basename = re.sub("[^A-Za-z]", "", name)
         self.num = num
         self.__weight = None
         self.__color = None
         self.__radius = numpy.nan
-        self._dbcache = {prop: [] for prop in ('f0', 'f1', 'f2', 'f')}
+        self._dbcache = {prop: [] for prop in ("f0", "f1", "f2", "f")}
 
     def __key__(self):
-        """ key function to return the elements number """
+        """Key function to return the elements number"""
         return self.num
 
     def __lt__(self, other_el):
-        """ make elements sortable by their key """
+        """Make elements sortable by their key"""
         return self.__key__() < other_el.__key__()
 
     @property
@@ -93,8 +94,7 @@ class Atom:
         return self.__radius
 
     def get_cache(self, prop, key):
-        """
-        check if a cached value exists to speed up repeated database requests
+        """Check cached value to speed up repeated database requests.
 
         Returns
         -------
@@ -102,6 +102,7 @@ class Atom:
             True then result contains the cached otherwise False and result is
             None
         result :    database value
+
         """
         history = self._dbcache[prop]
         for idx, (k, result) in enumerate(history):
@@ -111,9 +112,7 @@ class Atom:
         return False, None
 
     def set_cache(self, prop, key, result):
-        """
-        set result to be cached to speed up future calls
-        """
+        """Set result to be cached to speed up future calls"""
         history = self._dbcache[prop]
         if len(history) == self.max_cache_length:
             history.pop(-1)
@@ -121,43 +120,42 @@ class Atom:
 
     def f0(self, q):
         key = get_key(q)
-        f, res = self.get_cache('f0', key)
+        f, res = self.get_cache("f0", key)
         if f:
             return res
         _db.SetMaterial(self.basename)
         res = _db.GetF0(q, self.ostate)
-        self.set_cache('f0', key, res)
+        self.set_cache("f0", key, res)
         return res
 
-    def f1(self, en='config'):
+    def f1(self, en="config"):
         key = get_key(en)
-        f, res = self.get_cache('f1', key)
+        f, res = self.get_cache("f1", key)
         if f:
             return res
-        if isinstance(en, str) and en == 'config':
+        if isinstance(en, str) and en == "config":
             en = utilities.energy(config.ENERGY)
 
         _db.SetMaterial(self.basename)
         res = _db.GetF1(utilities.energy(en))
-        self.set_cache('f1', key, res)
+        self.set_cache("f1", key, res)
         return res
 
-    def f2(self, en='config'):
+    def f2(self, en="config"):
         key = get_key(en)
-        f, res = self.get_cache('f2', key)
+        f, res = self.get_cache("f2", key)
         if f:
             return res
-        if isinstance(en, str) and en == 'config':
+        if isinstance(en, str) and en == "config":
             en = utilities.energy(config.ENERGY)
 
         _db.SetMaterial(self.basename)
         res = _db.GetF2(utilities.energy(en))
-        self.set_cache('f2', key, res)
+        self.set_cache("f2", key, res)
         return res
 
-    def f(self, q, en='config'):
-        """
-        function to calculate the atomic structure factor F
+    def f(self, q, en="config"):
+        """Function to calculate the atomic structure factor F
 
         Parameters
         ----------
@@ -171,14 +169,15 @@ class Atom:
         -------
         float or array-like
             value(s) of the atomic structure factor
+
         """
         key = get_key(q, en)
-        f, res = self.get_cache('f', key)
+        f, res = self.get_cache("f", key)
         if f:
             return res
 
-        res = self.f0(q) + self.f1(en) + 1.j * self.f2(en)
-        self.set_cache('f', key, res)
+        res = self.f0(q) + self.f1(en) + 1.0j * self.f2(en)
+        self.set_cache("f", key, res)
         return res
 
     def __str__(self):
