@@ -72,30 +72,30 @@ class FitModel(Model):
         # add LayerStack parameters
         for layer in self.lmodel.lstack:
             for param in self.lmodel.lstack_params:
-                funcstr += f'{layer.name}_{param}, '
+                funcstr += f"{layer.name}_{param}, "
             if self.lmodel.lstack_structural_params:
                 for param in layer._structural_params:
-                    funcstr += f'{layer.name}_{param}, '
+                    funcstr += f"{layer.name}_{param}, "
         funcstr += "lmodel=self.lmodel, **kwargs):\n"
         # define modelfunc content
         for p in self.lmodel.fit_paramnames:
             funcstr += f"    setattr(lmodel, '{p}', {p})\n"
-        for i, l in enumerate(self.lmodel.lstack):
+        for i, layer in enumerate(self.lmodel.lstack):
             for param in self.lmodel.lstack_params:
-                varname = f'{l.name}_{param}'
+                varname = f"{layer.name}_{param}"
                 cmd = "    setattr(lmodel.lstack[{}], '{}', {})\n"
                 funcstr += cmd.format(i, param, varname)
             if self.lmodel.lstack_structural_params:
-                for param in l._structural_params:
-                    varname = f'{l.name}_{param}'
+                for param in layer._structural_params:
+                    varname = f"{layer.name}_{param}"
                     cmd = "    setattr(lmodel.lstack[{}], '{}', {})\n"
                     funcstr += cmd.format(i, param, varname)
         # perform actual model calculation
         funcstr += "    return lmodel.simulate(x, **kwargs)"
 
-        namespace = {'self': self}
-        exec(funcstr, {'lmodel': self.lmodel}, namespace)
-        self.func = namespace['func']
+        namespace = {"self": self}
+        exec(funcstr, {"lmodel": self.lmodel}, namespace)
+        self.func = namespace["func"]
         self.emetricfunc = numpy.log10 if self.elog else lambda x: x
 
         def _residual(params, data, weights, **kwargs):
@@ -109,15 +109,20 @@ class FitModel(Model):
             scale = self.emetricfunc
             model = scale(self.eval(params, **kwargs))
             sdata = scale(data)
-            mask = numpy.logical_and(numpy.isfinite(model),
-                                     numpy.isfinite(sdata))
+            mask = numpy.logical_and(
+                numpy.isfinite(model), numpy.isfinite(sdata)
+            )
             diff = model[mask] - sdata[mask]
             if weights is not None and scale(1) == 1:
                 diff *= weights
             return numpy.asarray(diff).ravel()
 
-        super().__init__(self.func, independent_vars='x',
-                         name=self.lmodel.__class__.__name__, **kwargs)
+        super().__init__(
+            self.func,
+            independent_vars="x",
+            name=self.lmodel.__class__.__name__,
+            **kwargs,
+        )
         self._residual = _residual
         # set default parameter hints
         self._default_hints()
@@ -142,8 +147,16 @@ class FitModel(Model):
         self.xmin = xmin
         self.xmax = xmax
 
-    def fit(self, data, params, x, weights=None, fit_kws=None, lmfit_kws=None,
-            **kwargs):
+    def fit(
+        self,
+        data,
+        params,
+        x,
+        weights=None,
+        fit_kws=None,
+        lmfit_kws=None,
+        **kwargs,
+    ):
         """
         wrapper around lmfit.Model.fit which enables plotting during the
         fitting
@@ -180,7 +193,7 @@ class FitModel(Model):
                 if not self.figname:
                     self.plot = False
                 else:
-                    f, plt = utilities.import_matplotlib_pyplot('XU.simpack')
+                    f, plt = utilities.import_matplotlib_pyplot("XU.simpack")
                     self.plt = plt
                     self.plot = f
 
@@ -191,27 +204,33 @@ class FitModel(Model):
                 if isinstance(self.figname, str):
                     self.fig = self.plt.figure(self.figname)
                 else:
-                    self.fig = self.plt.figure('XU:FitModel')
+                    self.fig = self.plt.figure("XU:FitModel")
                 self.plt.clf()
                 self.ax = self.plt.subplot(111)
 
                 if weights is not None:
                     eline = self.ax.errorbar(
-                        x, data, yerr=1/weights, ecolor='0.3', fmt='ok',
-                        errorevery=int(x.size/80), label='data')[0]
+                        x,
+                        data,
+                        yerr=1 / weights,
+                        ecolor="0.3",
+                        fmt="ok",
+                        errorevery=int(x.size / 80),
+                        label="data",
+                    )[0]
                 else:
-                    eline, = self.ax.plot(x, data, 'ok', label='data')
+                    (eline,) = self.ax.plot(x, data, "ok", label="data")
                 if verbose:
-                    self.ax.plot(x, model, '-', color='0.5', label='initial')
+                    self.ax.plot(x, model, "-", color="0.5", label="initial")
                 if eline:
-                    self.zord = eline.zorder+2
+                    self.zord = eline.zorder + 2
                 else:
                     self.zord = 1
                 if self.logscale:
                     self.ax.set_yscale("log")
                 self.fline = None
 
-            def showplot(self, xlab, ylab='Intensity (arb. u.)'):
+            def showplot(self, xlab, ylab="Intensity (arb. u.)"):
                 if not self.plot:
                     return
                 self.plt.xlabel(xlab)
@@ -228,8 +247,9 @@ class FitModel(Model):
                 except ValueError:
                     return
                 if self.fline is None:
-                    self.fline, = self.ax.plot(
-                        x, newmodel, '-r', lw=2, label='fit', zorder=self.zord)
+                    (self.fline,) = self.ax.plot(
+                        x, newmodel, "-r", lw=2, label="fit", zorder=self.zord
+                    )
                 else:
                     self.fline.set_data(x, newmodel)
                 canvas = self.fig.canvas  # see plt.draw function (avoid show!)
@@ -239,8 +259,9 @@ class FitModel(Model):
             def addfullmodelline(self, x, y):
                 if not self.plot:
                     return
-                self.ax.plot(x, y, '-g', lw=1, label='full model',
-                             zorder=self.zord-1)
+                self.ax.plot(
+                    x, y, "-g", lw=1, label="full model", zorder=self.zord - 1
+                )
 
         if self.mask:
             mask = self.mask
@@ -259,23 +280,32 @@ class FitModel(Model):
         # create callback function
         def cb_func(params, niter, resid, *args, **kwargs):
             if self.verbose:
-                print(f'{niter:04d} {numpy.sum(resid ** 2):12.3e}')
+                print(f"{niter:04d} {numpy.sum(resid**2):12.3e}")
             if self.fitplot.plot and niter % 20 == 0:
-                self.fitplot.updatemodelline(kwargs['x'],
-                                             self.eval(params, **kwargs))
+                self.fitplot.updatemodelline(
+                    kwargs["x"], self.eval(params, **kwargs)
+                )
 
         # perform fitting
         lmfit_kws.update(kwargs)  # add kwargs for function call
-        res = super().fit(data[mask], params, x=x[mask], weights=mweights,
-                          fit_kws=fit_kws, iter_cb=cb_func, **lmfit_kws)
+        res = super().fit(
+            data[mask],
+            params,
+            x=x[mask],
+            weights=mweights,
+            fit_kws=fit_kws,
+            iter_cb=cb_func,
+            **lmfit_kws,
+        )
 
         # final update of plot
         if self.fitplot.plot:
             try:
                 self.fitplot.plt.sca(self.fitplot.ax)
             except ValueError:
-                self.fitplot.plot_init(x, data, weights, initmodel, mask,
-                                       self.verbose)
+                self.fitplot.plot_init(
+                    x, data, weights, initmodel, mask, self.verbose
+                )
             fittedmodel = self.eval(res.params, x=x, **kwargs)
             self.fitplot.addfullmodelline(x, fittedmodel)
             self.fitplot.updatemodelline(x[mask], fittedmodel[mask])
@@ -290,30 +320,33 @@ class FitModel(Model):
         # general parameters
         for pn in self.lmodel.fit_paramnames:
             self.set_param_hint(pn, value=getattr(self.lmodel, pn), vary=False)
-        for pn in ('I0', 'background'):
+        for pn in ("I0", "background"):
             self.set_param_hint(pn, vary=True, min=0)
-        self.set_param_hint('resolution_width', min=0, vary=False)
-        self.set_param_hint('energy', min=1000, vary=False)
+        self.set_param_hint("resolution_width", min=0, vary=False)
+        self.set_param_hint("energy", min=1000, vary=False)
 
         # parameters of the layerstack
         for lay in self.lmodel.lstack:
             for param in self.lmodel.lstack_params:
-                varname = f'{lay.name}_{param}'
+                varname = f"{lay.name}_{param}"
                 self.set_param_hint(varname, value=getattr(lay, param), min=0)
-                if param == 'density':
-                    self.set_param_hint(varname, max=1.5*lay.material.density)
-                if param == 'thickness':
-                    self.set_param_hint(varname, max=2*lay.thickness)
-                if param == 'roughness':
+                if param == "density":
+                    self.set_param_hint(
+                        varname, max=1.5 * lay.material.density
+                    )
+                if param == "thickness":
+                    self.set_param_hint(varname, max=2 * lay.thickness)
+                if param == "roughness":
                     self.set_param_hint(varname, max=50)
             if self.lmodel.lstack_structural_params:
                 for param in lay._structural_params:
-                    varname = f'{lay.name}_{param}'
-                    self.set_param_hint(varname, value=getattr(lay, param),
-                                        vary=False)
-                    if 'occupation' in param:
+                    varname = f"{lay.name}_{param}"
+                    self.set_param_hint(
+                        varname, value=getattr(lay, param), vary=False
+                    )
+                    if "occupation" in param:
                         self.set_param_hint(varname, min=0, max=1)
-                    if 'biso' in param:
+                    if "biso" in param:
                         self.set_param_hint(varname, min=0, max=5)
         if self.lmodel.lstack[0].thickness == numpy.inf:
             varname = f"{self.lmodel.lstack[0].name}_thickness"
