@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2014 Dominik Kriegner <dominik.kriegner@gmail.com>
+ * Copyright (C) 2014-2025 Dominik Kriegner <dominik.kriegner@gmail.com>
  *
  ******************************************************************************
  *
@@ -25,60 +25,60 @@
 #include "gridder.h"
 #include "gridder_utils.h"
 
-PyObject* pyfuzzygridder1d(PyObject *self, PyObject *args)
-{
-    PyArrayObject *py_x = NULL, *py_data = NULL,
-                  *py_output = NULL, *py_norm = NULL;
 
+PyObject* pyfuzzygridder1d(PyObject *self, PyObject *args) {
+    PyArrayObject *px = NULL, *pdata = NULL, *poutput = NULL, *pnorm = NULL;
+    PyObject *xobj = NULL, *dataobj = NULL, *outputobj = NULL, *normobj = NULL;
     double *x = NULL, *data = NULL, *odata = NULL, *norm = NULL;
     double xmin, xmax, fuzzywidth;
     unsigned int nx;
     int flags;
     int n, result;
+    PyObject *return_value = NULL;
 
     if (!PyArg_ParseTuple(args, "O!O!IddO!|O!di",
-                         &PyArray_Type, &py_x,
-                         &PyArray_Type, &py_data,
+                         &PyArray_Type, &xobj,
+                         &PyArray_Type, &dataobj,
                          &nx, &xmin, &xmax,
-                         &PyArray_Type, &py_output,
-                         &PyArray_Type, &py_norm,
-                         &fuzzywidth, &flags))
-        return NULL;
-
-    /* have to check input variables */
-    PYARRAY_CHECK(py_x, 1, NPY_DOUBLE, "x-axis must be a 1D double array!");
-    PYARRAY_CHECK(py_data, 1, NPY_DOUBLE,
-                  "input data must be a 1D double array!");
-    PYARRAY_CHECK(py_output, 1, NPY_DOUBLE,
-                  "ouput data must be a 1D double array!");
-    if (py_norm != NULL)
-        PYARRAY_CHECK(py_norm, 1, NPY_DOUBLE,
-                      "norm data must be a 1D double array!");
-
-    /* get data */
-    x = (double *) PyArray_DATA(py_x);
-    data = (double *) PyArray_DATA(py_data);
-    odata = (double *) PyArray_DATA(py_output);
-    if (py_norm != NULL) {
-        norm = (double *) PyArray_DATA(py_norm);
+                         &PyArray_Type, &outputobj,
+                         &PyArray_Type, &normobj,
+                         &fuzzywidth, &flags)) {
+        return NULL; // Return NULL directly if parsing fails
     }
 
-    /* get the total number of points */
-    n = (int) PyArray_SIZE(py_x);
+    px = check_and_convert_to_contiguous(xobj, 1, NPY_DOUBLE, "x-axis");
+    if (!px) goto cleanup;
 
-    /* call the actual gridder routine */
-    result = fuzzygridder1d(x, data, n, nx, xmin, xmax, odata,
-                            norm, fuzzywidth, flags);
+    pdata = check_and_convert_to_contiguous(dataobj, 1, NPY_DOUBLE, "input data");
+    if (!pdata) goto cleanup;
 
-    /* clean up */
-    Py_DECREF(py_x);
-    Py_DECREF(py_data);
-    Py_DECREF(py_output);
-    if (py_norm != NULL) {
-        Py_DECREF(py_norm);
+    poutput = check_and_convert_to_contiguous(outputobj, 1, NPY_DOUBLE, "output data");
+    if (!poutput) goto cleanup;
+
+    if (normobj != NULL) {
+        pnorm = check_and_convert_to_contiguous(normobj, 1, NPY_DOUBLE, "norm");
+        if (!pnorm) goto cleanup;
     }
 
-    return Py_BuildValue("i", &result);
+    x = (double *)PyArray_DATA(px);
+    data = (double *)PyArray_DATA(pdata);
+    odata = (double *)PyArray_DATA(poutput);
+    if (pnorm != NULL) {
+        norm = (double *)PyArray_DATA(pnorm);
+    }
+
+    n = (int)PyArray_SIZE(px);
+
+    result = fuzzygridder1d(x, data, n, nx, xmin, xmax, odata, norm, fuzzywidth, flags);
+
+    return_value = Py_BuildValue("i", result);
+
+cleanup:
+    Py_XDECREF(pnorm);
+    Py_XDECREF(poutput);
+    Py_XDECREF(pdata);
+    Py_XDECREF(px);
+    return return_value;
 }
 
 /*---------------------------------------------------------------------------*/
@@ -197,57 +197,58 @@ int fuzzygridder1d(double *x, double *data, unsigned int n,
 /*---------------------------------------------------------------------------*/
 PyObject* pygridder1d(PyObject *self, PyObject *args)
 {
-    PyArrayObject *py_x = NULL, *py_data = NULL,
-                  *py_output = NULL, *py_norm = NULL;
-
+    PyArrayObject *px = NULL, *pdata = NULL, *poutput = NULL, *pnorm = NULL;
+    PyObject *xobj = NULL, *dataobj = NULL, *outputobj = NULL, *normobj = NULL;
     double *x = NULL, *data = NULL, *odata = NULL, *norm = NULL;
     double xmin, xmax;
     unsigned int nx;
     int flags;
     int n, result;
+    PyObject *return_value = NULL;
 
     if (!PyArg_ParseTuple(args, "O!O!IddO!|O!i",
-                         &PyArray_Type, &py_x,
-                         &PyArray_Type, &py_data,
+                         &PyArray_Type, &xobj,
+                         &PyArray_Type, &dataobj,
                          &nx, &xmin, &xmax,
-                         &PyArray_Type, &py_output,
-                         &PyArray_Type, &py_norm,
-                         &flags))
+                         &PyArray_Type, &outputobj,
+                         &PyArray_Type, &normobj,
+                         &flags)) {
         return NULL;
-
-    /* have to check input variables */
-    PYARRAY_CHECK(py_x, 1, NPY_DOUBLE, "x-axis must be a 1D double array!");
-    PYARRAY_CHECK(py_data, 1, NPY_DOUBLE,
-                  "input data must be a 1D double array!");
-    PYARRAY_CHECK(py_output, 1, NPY_DOUBLE,
-                  "ouput data must be a 1D double array!");
-    if (py_norm != NULL)
-        PYARRAY_CHECK(py_norm, 1, NPY_DOUBLE,
-                      "norm data must be a 1D double array!");
-
-    /* get data */
-    x = (double *) PyArray_DATA(py_x);
-    data = (double *) PyArray_DATA(py_data);
-    odata = (double *) PyArray_DATA(py_output);
-    if (py_norm != NULL) {
-        norm = (double *) PyArray_DATA(py_norm);
     }
 
-    /* get the total number of points */
-    n = (int) PyArray_SIZE(py_x);
+    px = check_and_convert_to_contiguous(xobj, 1, NPY_DOUBLE, "x-axis");
+    if (!px) goto cleanup;
+
+    pdata = check_and_convert_to_contiguous(dataobj, 1, NPY_DOUBLE, "input data");
+    if (!pdata) goto cleanup;
+
+    poutput = check_and_convert_to_contiguous(outputobj, 1, NPY_DOUBLE, "output data");
+    if (!poutput) goto cleanup;
+
+    if (normobj != NULL) {
+        pnorm = check_and_convert_to_contiguous(normobj, 1, NPY_DOUBLE, "norm");
+        if (!pnorm) goto cleanup;
+    }
+
+    x = (double *)PyArray_DATA(px);
+    data = (double *)PyArray_DATA(pdata);
+    odata = (double *)PyArray_DATA(poutput);
+    if (pnorm != NULL) {
+        norm = (double *)PyArray_DATA(pnorm);
+    }
+
+    n = (int)PyArray_SIZE(px);
 
-    /* call the actual gridder routine */
     result = gridder1d(x, data, n, nx, xmin, xmax, odata, norm, flags);
 
-    /* clean up */
-    Py_DECREF(py_x);
-    Py_DECREF(py_data);
-    Py_DECREF(py_output);
-    if (py_norm != NULL) {
-        Py_DECREF(py_norm);
-    }
+    return_value = Py_BuildValue("i", result);
 
-    return Py_BuildValue("i", &result);
+cleanup:
+    Py_XDECREF(pnorm);
+    Py_XDECREF(poutput);
+    Py_XDECREF(pdata);
+    Py_XDECREF(px);
+    return return_value;
 }
 
 /*---------------------------------------------------------------------------*/
@@ -336,4 +337,3 @@ int gridder1d(double *x, double *data, unsigned int n,
 
     return 0;
 }
-
