@@ -15,7 +15,7 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Copyright (C) 2013 Eugen Wintersberger <eugen.wintersberger@desy.de>
- * Copyright (C) 2013, 2015 Dominik Kriegner <dominik.kriegner@gmail.com>
+ * Copyright (C) 2013-2025 Dominik Kriegner <dominik.kriegner@gmail.com>
  *
  ******************************************************************************
  *
@@ -26,73 +26,83 @@
 #include "gridder.h"
 #include "gridder_utils.h"
 
-PyObject* pyfuzzygridder3d(PyObject *self, PyObject *args)
-{
-    PyArrayObject *py_x = NULL, *py_y = NULL, *py_z = NULL, *py_data = NULL,
-                  *py_output = NULL, *py_norm = NULL;
+#include <Python.h>
+#include <numpy/arrayobject.h>
+#include <math.h>
+#include <stdio.h>
+#include <stdlib.h>
 
-    double *x = NULL, *y = NULL, *z = NULL, *data = NULL, *odata = NULL,
-           *norm = NULL;
+
+PyObject* pyfuzzygridder3d(PyObject *self, PyObject *args) {
+    PyArrayObject *px = NULL, *py = NULL, *pz = NULL, *pdata = NULL, *poutput = NULL, *pnorm = NULL;
+    double *x = NULL, *y = NULL, *z = NULL, *data = NULL, *odata = NULL, *norm = NULL;
     double xmin, xmax, ymin, ymax, zmin, zmax, wx, wy, wz;
     unsigned int nx, ny, nz;
     int flags;
     int n, result;
+    PyObject *return_value = NULL;
+
+    PyObject *xobj = NULL, *yobj = NULL, *zobj = NULL, *dataobj = NULL, *outputobj = NULL, *normobj = NULL;
 
     if (!PyArg_ParseTuple(args, "O!O!O!O!IIIddddddO!|O!dddi",
-                         &PyArray_Type, &py_x,
-                         &PyArray_Type, &py_y,
-                         &PyArray_Type, &py_z,
-                         &PyArray_Type, &py_data,
+                         &PyArray_Type, &xobj,
+                         &PyArray_Type, &yobj,
+                         &PyArray_Type, &zobj,
+                         &PyArray_Type, &dataobj,
                          &nx, &ny, &nz,
                          &xmin, &xmax, &ymin, &ymax, &zmin, &zmax,
-                         &PyArray_Type, &py_output,
-                         &PyArray_Type, &py_norm,
+                         &PyArray_Type, &outputobj,
+                         &PyArray_Type, &normobj,
                          &wx, &wy, &wz, &flags)) {
         return NULL;
     }
 
-    /* check input variables */
-    PYARRAY_CHECK(py_x, 1, NPY_DOUBLE, "x-axis must be a 1D double array!");
-    PYARRAY_CHECK(py_y, 1, NPY_DOUBLE, "y-axis must be a 1D double array!");
-    PYARRAY_CHECK(py_z, 1, NPY_DOUBLE, "z-axis must be a 1D double array!");
-    PYARRAY_CHECK(py_data, 1, NPY_DOUBLE,
-                  "input data must be a 1D double array!");
-    PYARRAY_CHECK(py_output, 3, NPY_DOUBLE,
-                  "ouput data must be a 2D double array!");
-    if (py_norm != NULL) {
-        PYARRAY_CHECK(py_norm, 3, NPY_DOUBLE,
-                      "norm data must be a 2D double array!");
+    px = check_and_convert_to_contiguous(xobj, 1, NPY_DOUBLE, "x-axis");
+    if (!px) goto cleanup;
+
+    py = check_and_convert_to_contiguous(yobj, 1, NPY_DOUBLE, "y-axis");
+    if (!py) goto cleanup;
+
+    pz = check_and_convert_to_contiguous(zobj, 1, NPY_DOUBLE, "z-axis");
+    if (!pz) goto cleanup;
+
+    pdata = check_and_convert_to_contiguous(dataobj, 1, NPY_DOUBLE, "input data");
+    if (!pdata) goto cleanup;
+
+    poutput = check_and_convert_to_contiguous(outputobj, 3, NPY_DOUBLE, "output data");
+    if (!poutput) goto cleanup;
+
+    if (normobj != NULL) {
+        pnorm = check_and_convert_to_contiguous(normobj, 3, NPY_DOUBLE, "norm");
+        if (!pnorm) goto cleanup;
     }
 
-    /* get data */
-    x = (double *) PyArray_DATA(py_x);
-    y = (double *) PyArray_DATA(py_y);
-    z = (double *) PyArray_DATA(py_z);
-    data = (double *) PyArray_DATA(py_data);
-    odata = (double *) PyArray_DATA(py_output);
-    if (py_norm != NULL) {
-        norm = (double *) PyArray_DATA(py_norm);
+    x = (double *)PyArray_DATA(px);
+    y = (double *)PyArray_DATA(py);
+    z = (double *)PyArray_DATA(pz);
+    data = (double *)PyArray_DATA(pdata);
+    odata = (double *)PyArray_DATA(poutput);
+    if (pnorm != NULL) {
+        norm = (double *)PyArray_DATA(pnorm);
     }
 
-    /* get the total number of points */
-    n = (int) PyArray_SIZE(py_x);
+    n = (int)PyArray_SIZE(px);
 
-    /* call the actual gridder routine */
     result = fuzzygridder3d(x, y, z, data, n, nx, ny, nz,
-                            xmin, xmax, ymin, ymax, zmin, zmax, odata, norm,
-                            wx, wy, wz, flags);
+                           xmin, xmax, ymin, ymax, zmin, zmax, odata, norm,
+                           wx, wy, wz, flags);
 
-    /* clean up */
-    Py_DECREF(py_x);
-    Py_DECREF(py_y);
-    Py_DECREF(py_z);
-    Py_DECREF(py_data);
-    Py_DECREF(py_output);
-    if (py_norm != NULL) {
-        Py_DECREF(py_norm);
-    }
+    return_value = Py_BuildValue("i", result);
 
-    return Py_BuildValue("i", &result);
+cleanup:
+    Py_XDECREF(pnorm);
+    Py_XDECREF(poutput);
+    Py_XDECREF(pdata);
+    Py_XDECREF(pz);
+    Py_XDECREF(py);
+    Py_XDECREF(px);
+
+    return return_value;
 }
 
 /*---------------------------------------------------------------------------*/
@@ -274,70 +284,74 @@ int fuzzygridder3d(double *x, double *y, double *z, double *data,
 /*---------------------------------------------------------------------------*/
 PyObject* pygridder3d(PyObject *self, PyObject *args)
 {
-    PyArrayObject *py_x = NULL, *py_y = NULL, *py_z = NULL, *py_data = NULL,
-                  *py_output = NULL, *py_norm = NULL;
-
-    double *x = NULL, *y = NULL, *z = NULL, *data = NULL, *odata = NULL,
-           *norm = NULL;
+    PyArrayObject *px = NULL, *py = NULL, *pz = NULL, *pdata = NULL, *poutput = NULL, *pnorm = NULL;
+    double *x = NULL, *y = NULL, *z = NULL, *data = NULL, *odata = NULL, *norm = NULL;
     double xmin, xmax, ymin, ymax, zmin, zmax;
     unsigned int nx, ny, nz;
     int flags;
     int n, result;
+    PyObject *return_value = NULL;
+
+    PyObject *xobj = NULL, *yobj = NULL, *zobj = NULL, *dataobj = NULL, *outputobj = NULL, *normobj = NULL;
 
     if (!PyArg_ParseTuple(args, "O!O!O!O!IIIddddddO!|O!i",
-                         &PyArray_Type, &py_x,
-                         &PyArray_Type, &py_y,
-                         &PyArray_Type, &py_z,
-                         &PyArray_Type, &py_data,
+                         &PyArray_Type, &xobj,
+                         &PyArray_Type, &yobj,
+                         &PyArray_Type, &zobj,
+                         &PyArray_Type, &dataobj,
                          &nx, &ny, &nz,
                          &xmin, &xmax, &ymin, &ymax, &zmin, &zmax,
-                         &PyArray_Type, &py_output,
-                         &PyArray_Type, &py_norm,
+                         &PyArray_Type, &outputobj,
+                         &PyArray_Type, &normobj,
                          &flags)) {
         return NULL;
     }
 
-    /* check input variables */
-    PYARRAY_CHECK(py_x, 1, NPY_DOUBLE, "x-axis must be a 1D double array!");
-    PYARRAY_CHECK(py_y, 1, NPY_DOUBLE, "y-axis must be a 1D double array!");
-    PYARRAY_CHECK(py_z, 1, NPY_DOUBLE, "z-axis must be a 1D double array!");
-    PYARRAY_CHECK(py_data, 1, NPY_DOUBLE,
-                  "input data must be a 1D double array!");
-    PYARRAY_CHECK(py_output, 3, NPY_DOUBLE,
-                  "ouput data must be a 2D double array!");
-    if (py_norm != NULL) {
-        PYARRAY_CHECK(py_norm, 3, NPY_DOUBLE,
-                      "norm data must be a 2D double array!");
+    px = check_and_convert_to_contiguous(xobj, 1, NPY_DOUBLE, "x-axis");
+    if (!px) goto cleanup;
+
+    py = check_and_convert_to_contiguous(yobj, 1, NPY_DOUBLE, "y-axis");
+    if (!py) goto cleanup;
+
+    pz = check_and_convert_to_contiguous(zobj, 1, NPY_DOUBLE, "z-axis");
+    if (!pz) goto cleanup;
+
+    pdata = check_and_convert_to_contiguous(dataobj, 1, NPY_DOUBLE, "input data");
+    if (!pdata) goto cleanup;
+
+    poutput = check_and_convert_to_contiguous(outputobj, 3, NPY_DOUBLE, "output data");
+    if (!poutput) goto cleanup;
+
+    if (normobj != NULL) {
+        pnorm = check_and_convert_to_contiguous(normobj, 3, NPY_DOUBLE, "norm");
+        if (!pnorm) goto cleanup;
     }
 
-    /* get data */
-    x = (double *) PyArray_DATA(py_x);
-    y = (double *) PyArray_DATA(py_y);
-    z = (double *) PyArray_DATA(py_z);
-    data = (double *) PyArray_DATA(py_data);
-    odata = (double *) PyArray_DATA(py_output);
-    if (py_norm != NULL) {
-        norm = (double *) PyArray_DATA(py_norm);
+    x = (double *)PyArray_DATA(px);
+    y = (double *)PyArray_DATA(py);
+    z = (double *)PyArray_DATA(pz);
+    data = (double *)PyArray_DATA(pdata);
+    odata = (double *)PyArray_DATA(poutput);
+    if (pnorm != NULL) {
+        norm = (double *)PyArray_DATA(pnorm);
     }
 
-    /* get the total number of points */
-    n = (int) PyArray_SIZE(py_x);
+    n = (int)PyArray_SIZE(px);
 
-    /* call the actual gridder routine */
     result = gridder3d(x, y, z, data, n, nx, ny, nz,
-                       xmin, xmax, ymin, ymax, zmin, zmax, odata, norm, flags);
+                      xmin, xmax, ymin, ymax, zmin, zmax, odata, norm, flags);
 
-    /* clean up */
-    Py_DECREF(py_x);
-    Py_DECREF(py_y);
-    Py_DECREF(py_z);
-    Py_DECREF(py_data);
-    Py_DECREF(py_output);
-    if (py_norm != NULL) {
-        Py_DECREF(py_norm);
-    }
+    return_value = Py_BuildValue("i", result);
 
-    return Py_BuildValue("i", &result);
+cleanup:
+    Py_XDECREF(pnorm);
+    Py_XDECREF(poutput);
+    Py_XDECREF(pdata);
+    Py_XDECREF(pz);
+    Py_XDECREF(py);
+    Py_XDECREF(px);
+
+    return return_value;
 }
 
 /*---------------------------------------------------------------------------*/
@@ -436,4 +450,3 @@ int gridder3d(double *x, double *y, double *z, double *data, unsigned int n,
 
     return 0;
 }
-
