@@ -15,48 +15,14 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Copyright (C) 2014 Eugen Wintersberger <eugen.wintersberger@gmail.com>
+ * Copyright (C) 2025 Dominik Kriegner <dominik.kriegner@gmail.com>
 */
 #pragma once
 
 #define PY_SSIZE_T_CLEAN
 #include <Python.h>
 #include <math.h>
-
-/*****************************************************************************
- * NUMPY specific macros and header files
- ****************************************************************************/
-/*
- * need to make some definitions before loading the arrayobject.h
- * header file
- */
-#define NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION
-#define PY_ARRAY_UNIQUE_SYMBOL XU_UNIQUE_SYMBOL
-#define NO_IMPORT_ARRAY
-#include <numpy/arrayobject.h>
-
-/*
- * set numpy API specific macros
- */
-#if NPY_FEATURE_VERSION < 0x00000007
-    #define NPY_ARRAY_ALIGNED       NPY_ALIGNED
-    #define NPY_ARRAY_C_CONTIGUOUS  NPY_C_CONTIGUOUS
-#endif
-
-/*
- * define a macro to check a numpy array. This should mabye go into a
- * function in future.
- */
-#define PYARRAY_CHECK(array, dims, type, msg) \
-    array = (PyArrayObject *) PyArray_FROM_OTF((PyObject *) array, \
-                                               type, \
-                                               NPY_ARRAY_C_CONTIGUOUS | \
-                                               NPY_ARRAY_ALIGNED); \
-    if (PyArray_NDIM(array) != dims ||  \
-        PyArray_TYPE(array) != type) {\
-        PyErr_SetString(PyExc_ValueError, msg); \
-        return NULL; \
-    }
-
+#include "array_utils.h"
 
 /*****************************************************************************
  * Windows build related macros
@@ -95,10 +61,11 @@
 /*
  * include OpenMP header is required
  */
-#ifdef __OPENMP__
+#ifdef _OPENMP
 #include <omp.h>
-#endif
 
 #define OMPSETNUMTHREADS(nth) \
     if (nth == 0) omp_set_num_threads(omp_get_max_threads());\
     else omp_set_num_threads(nth);
+
+#endif
